@@ -25,35 +25,29 @@
 #include <Kdelibs4ConfigMigrator>
 
 #include <QApplication>
-#include <QtCore/QCommandLineParser>
+#include <QCommandLineParser>
 #include "kmenuedit.h"
-#ifndef Q_OS_WIN
-#include "khotkeys.h"
-#endif
 
 static const char description[] = I18N_NOOP("KDE menu editor");
 
-static KMenuEdit *menuEdit = 0;
+static KMenuEdit *menuEdit = nullptr;
 
 class KMenuApplication : public QApplication
 {
 public:
-   KMenuApplication(int &argc, char **argv)
-    : QApplication(argc, argv)
+    KMenuApplication(int &argc, char **argv)
+        : QApplication(argc, argv)
     {
         QCoreApplication::setApplicationName(QStringLiteral("kmenuedit"));
-        QCoreApplication::setApplicationVersion(PROJECT_VERSION);
+        QCoreApplication::setApplicationVersion(QLatin1String(PROJECT_VERSION));
         QCoreApplication::setOrganizationDomain(QStringLiteral("kde.org"));
         QApplication::setApplicationDisplayName(i18n("KDE Menu Editor"));
     }
-#ifdef WITH_HOTKEYS
-   virtual ~KMenuApplication() { KHotKeys::cleanup(); }
-#endif
 };
 
-
-extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
+extern "C" int Q_DECL_EXPORT kdemain(int argc, char **argv)
 {
+    KMenuApplication app(argc, argv);
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kmenuedit"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("kmenueditrc"));
     migrate.setUiFiles(QStringList() << QStringLiteral("kmenueditui.rc"));
@@ -63,7 +57,7 @@ extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
     KLocalizedString::setApplicationDomain("kmenuedit");
 
     KAboutData aboutData(QStringLiteral("kmenuedit"), i18n("KDE Menu Editor"),
-                         PROJECT_VERSION, i18n(description), KAboutLicense::GPL,
+                         QLatin1String(PROJECT_VERSION), i18n(description), KAboutLicense::GPL,
                          i18n("(C) 2000-2003, Waldo Bastian, Raffaele Sandrini, Matthias Elter"));
     aboutData.addAuthor(i18n("Waldo Bastian"), i18n("Maintainer"), QStringLiteral("bastian@kde.org"));
     aboutData.addAuthor(i18n("Raffaele Sandrini"), i18n("Previous Maintainer"), QStringLiteral("sandrini@kde.org"));
@@ -71,8 +65,6 @@ extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
     aboutData.addAuthor(i18n("Montel Laurent"), QString(), QStringLiteral("montel@kde.org"));
     KAboutData::setApplicationData(aboutData);
 
-    KMenuApplication app(argc, argv);
-
     KDBusService service(KDBusService::Unique);
 
     QCommandLineParser parser;
@@ -98,5 +90,5 @@ extern "C" int Q_DECL_EXPORT kdemain( int argc, char **argv )
     }
     menuEdit->show();
 
-    return  app.exec();
+    return app.exec();
 }
